@@ -22,19 +22,36 @@
 
 from gnuradio import gr
 from gnuradio import audio
+from optparse import OptionParser
 
-def build_graph ():
+def build_graph (input_device, output_device):
     sampling_freq = 48000
 
     fg = gr.flow_graph ()
-    src = audio.source (sampling_freq)
-    dst = audio.sink (sampling_freq)
-    fg.connect ((src, 0), (dst, 0))
-    fg.connect ((src, 1), (dst, 1))
+    src = audio.source (sampling_freq, input_device)
+    dst = audio.sink (sampling_freq, output_device)
+
+    # Determine the maximum number of outputs on the source and
+    # maximum number of inputs on the sink, then connect together
+    # the most channels we can without overlap
+    nchan = min (src.output_signature().max_streams(),
+                 dst.input_signature().max_streams())
+
+    for i in range (nchan):
+        fg.connect ((src, i), (dst, i))
+
     return fg
 
 if __name__ == '__main__':
-    fg = build_graph ()
+    parser = OptionParser ()
+    parser.add_option ("-i", "--input-device", type="string", default="hw:0,0",
+                        help="pcm input device name.  E.g., hw:0,0")
+    parser.add_option ("-o", "--output-device", type="string", default="hw:0,0",
+                        help="pcm output device name.  E.g., hw:0,0")
+    (options, args) = parser.parse_args ()
+
+    fg = build_graph (options.input_device, options.output_device)
+
     fg.start ()
     raw_input ('Press Enter to quit: ')
     fg.stop ()
