@@ -38,12 +38,21 @@ class app_flow_graph (stdgui.gui_flow_graph):
         parser = OptionParser (option_class=eng_option)
         parser.add_option ("-d", "--decim", type="int", default=16,
                            help="set fgpa decimation rate to DECIM")
-        parser.add_option ("-c", "--cordic-freq", type="eng_float", default=0,
-                           help="set Rx cordic frequency to FREQ", metavar="FREQ")
+        parser.add_option ("-c", "--ddc-freq", type="eng_float", default=0,
+                           help="set Rx DDC frequency to FREQ", metavar="FREQ")
+        parser.add_option ("-m", "--mux", type="intx", default=0x32103210,
+                           help="set fpga FR_RX_MUX register to MUX")
+        parser.add_option ("-g", "--gain", type="eng_float", default=0,
+                           help="set Rx PGA gain in dB (default 0 dB)")
         (options, args) = parser.parse_args ()
 
-        self.u = usrp.source_c (0, options.decim)
-        self.u.set_rx_freq (0, options.cordic_freq)
+        self.u = usrp.source_c (0, options.decim, 1, options.mux, 0)
+        self.u.set_rx_freq (0, options.ddc_freq)
+
+        self.u.set_pga (0, options.gain)
+        self.u.set_pga (1, options.gain)
+        
+        self.u.set_verbose (0)
         
         input_rate = self.u.adc_freq () / self.u.decim_rate ()
 
@@ -54,7 +63,7 @@ class app_flow_graph (stdgui.gui_flow_graph):
         # build small control area at bottom
         hbox = wx.BoxSizer (wx.HORIZONTAL)
         hbox.Add ((1, 1), 1, wx.EXPAND)
-        hbox.Add (wx.StaticText (panel, -1, "Set cordic freq: "), 0, wx.ALIGN_CENTER)
+        hbox.Add (wx.StaticText (panel, -1, "Set ddc freq: "), 0, wx.ALIGN_CENTER)
         self.tc_freq = wx.TextCtrl (panel, -1, "", style=wx.TE_PROCESS_ENTER)
         hbox.Add (self.tc_freq, 0, wx.ALIGN_CENTER)
         wx.EVT_TEXT_ENTER (self.tc_freq, self.tc_freq.GetId(), self.handle_text_enter)
@@ -71,13 +80,13 @@ class app_flow_graph (stdgui.gui_flow_graph):
         self.update_status_bar ()
 
     def update_status_bar (self):
-        cordic_freq = self.u.rx_freq (0)
+        ddc_freq = self.u.rx_freq (0)
         decim_rate = self.u.decim_rate ()
         sample_rate = self.u.adc_freq () / decim_rate
-        msg = "decim: %d  %sS/s  cordic: %s" % (
+        msg = "decim: %d  %sS/s  DDC: %s" % (
             decim_rate,
             eng_notation.num_to_str (sample_rate),
-            eng_notation.num_to_str (cordic_freq))
+            eng_notation.num_to_str (ddc_freq))
             
         self.frame.GetStatusBar().SetStatusText (msg, 1)
 
