@@ -9,7 +9,7 @@ from optparse import OptionParser
 class siggen (object):
     __slots__ = ['interp', 'waveform_type', 'waveform_ampl',
                  'waveform_freq', 'waveform_offset', 'fg', 'usrp',
-                 'siggen', 'noisegen', 'src' ]
+                 'siggen', 'noisegen', 'src', 'file_sink' ]
 
     def __init__ (self):
         # controllable values
@@ -59,7 +59,7 @@ class siggen (object):
         self.siggen.set_sampling_freq (self.usb_freq ())
         self.usrp.set_interp_rate (interp)
 
-    def set_cordic_freq (self, freq):
+    def set_duc_freq (self, freq):
         self.usrp.set_tx_freq (0, freq)
         
     def _instantiate_blocks (self):
@@ -76,6 +76,8 @@ class siggen (object):
         self.noisegen = gr.noise_source_c (gr.GR_UNIFORM,
                                            self.waveform_ampl)
 
+        # self.file_sink = gr.file_sink (gr.sizeof_gr_complex, "siggen.dat")
+
     def _configure_graph (self, type):
         was_running = self.fg.is_running ()
         if was_running:
@@ -83,6 +85,7 @@ class siggen (object):
         self.fg.disconnect_all ()
         if type == gr.GR_SIN_WAVE or type == gr.GR_CONST_WAVE:
             self.fg.connect (self.siggen, self.usrp)
+            # self.fg.connect (self.siggen, self.file_sink)
             self.siggen.set_waveform (type)
             self.src = self.siggen
         elif type == gr.GR_UNIFORM or type == gr.GR_GAUSSIAN:
@@ -106,7 +109,7 @@ def main ():
     parser.add_option ("--uniform", dest="type", action="store_const", const=gr.GR_UNIFORM,
                        help="generate Uniform random output")
 
-    parser.add_option ("-i", "--interp", type="eng_float", default=64,
+    parser.add_option ("-i", "--interp", type="int", default=64,
                        help="set fgpa interpolation rate to INTERP")
     parser.add_option ("-f", "--freq", type="eng_float", default=100e3,
                        help="set waveform frequency to FREQ")
@@ -114,8 +117,12 @@ def main ():
                        help="set waveform amplitude to AMPLITUDE", metavar="AMPL")
     parser.add_option ("-o", "--offset", type="eng_float", default=0,
                        help="set waveform offset to OFFSET")
-    parser.add_option ("-c", "--cordic-freq", type="eng_float", default=0,
-                       help="set Tx cordic frequency to FREQ", metavar="FREQ")
+    parser.add_option ("-c", "--duc-freq", type="eng_float", default=0,
+                       help="set Tx DUC frequency to FREQ", metavar="FREQ")
+    parser.add_option ("-n", "--nchannels", type="int", default=1,
+                       help="set number of output channels to NCHANNELS")
+    parser.add_option ("-m", "--mux", type="intx", default=0x98,
+                       help="set output mux register")
     (options, args) = parser.parse_args ()
 
     sg = siggen ()
@@ -124,8 +131,11 @@ def main ():
     sg.set_waveform_freq (options.freq)
     sg.set_waveform_ampl (options.amplitude)
     sg.set_waveform_offset (options.offset)
-    sg.set_cordic_freq (options.cordic_freq)
-    
+    sg.set_duc_freq (options.duc_freq)
+
+    sg.usrp.set_nchannels (options.nchannels)
+    sg.usrp.set_mux (options.mux)
+
     sg.start ()
     raw_input ('Press Enter to quit: ')
     sg.stop ()
