@@ -33,7 +33,7 @@ def build_graph ():
     rx_decim  = 32
     
     fg = gr.flow_graph ()
-    usrp_rx = usrp1.source_s (0, rx_decim, usrp1.FPGA_MODE_COUNTING)
+    usrp_rx = usrp1.source_s (0, rx_decim, 1, 0x32103210, usrp1.FPGA_MODE_COUNTING)
     sink = gr.check_counting_s ()
     fg.connect (usrp_rx, sink)
 
